.graph-container {
  box-sizing: border-box;
  height: 200px;
  background: #fff;
  background: linear-gradient(#f6f6f6 0%, #ffffff 50px);
  background: -o-linear-gradient(#f6f6f6 0, white 50px);
  background: -ms-linear-gradient(#f6f6f6 0, white 50px);
  background: -moz-linear-gradient(#f6f6f6 0, white 50px);
  background: -webkit-linear-gradient(#f6f6f6 0, white 50px);
  box-shadow: 0 3px 10px rgba(0, 0, 0, 0.15);
  -o-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  -ms-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  -webkit-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
}

.graph-placeholder {
  width: 100%;
  height: 100%;
  font-size: 14px;
  line-height: 1.2em;
}

.demo-container {
  position: relative;
  padding-left: 0.9375em;
  padding-right: 0.9375em;
  width: 50%;
  float: left;
  box-sizing: border-box;
  height: 200px;
  background: #fff;
  background: linear-gradient(#f6f6f6 0%, #ffffff 50px);
  background: -o-linear-gradient(#f6f6f6 0, white 50px);
  background: -ms-linear-gradient(#f6f6f6 0, white 50px);
  background: -moz-linear-gradient(#f6f6f6 0, white 50px);
  background: -webkit-linear-gradient(#f6f6f6 0, white 50px);
  box-shadow: 0 3px 10px rgba(0, 0, 0, 0.15);
  -o-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  -ms-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
  -webkit-box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
}

.demo-placeholder {
  width: 100%;
  height: 100%;
  font-size: 14px;
  line-height: 1.2em;
}
